@@ -2,7 +2,7 @@
 
 
 package App::Basis;
-$App::Basis::VERSION = '0.9';
+$App::Basis::VERSION = '1.0';
 use 5.014;
 use warnings;
 use strict;
@@ -90,7 +90,7 @@ sub debug {
         $_app_simple_objects{logger}->( $level, @debug ) if ( defined $_app_simple_objects{logger} );
     }
     else {
-        path($LOG_FILE)->append_utf8( strftime( '%Y-%m-%d %H:%M:%S', gmtime( time() ) ) . "[$level] " . join( ' ', @debug ) . "\n");
+        path($LOG_FILE)->append_utf8( strftime( '%Y-%m-%d %H:%M:%S', gmtime( time() ) ) . " [$level] " . join( ' ', @debug ) . "\n");
     }
 }
 
@@ -226,7 +226,7 @@ sub init_app {
         }
 
         # call the validation routine if we have one
-        if ( $full_options{$name}->{validate} ) {
+        if ( $_cmd_line_options{$name} && $full_options{$name}->{validate} ) {
             die "need to pass a coderef to validate for option '$name'" if ( !ref( $full_options{$name}->{validate} ) eq 'CODE' );
             die "Option '$name' has validate and should either also have a default or be required"
                 if ( !( $full_options{$name}->{required} || $full_options{$name}->{default} ) );
@@ -459,7 +459,7 @@ App::Basis - Simple way to create applications
 
 =head1 VERSION
 
-version 0.9
+version 1.0
 
 =head1 SYNOPSIS
 
